@@ -12,7 +12,7 @@ from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.1.17"
+__version__ = "0.1.20"
 
 if "CORGI_API_URL" not in os.environ:
     print("Must set CORGI_API_URL environment variable.")
@@ -29,7 +29,7 @@ OSIDB_AUTH_METHOD = os.getenv("OSIDB_AUTH_METHOD", "kerberos")
 
 # required to enable --search-community
 COMMUNITY_COMPONENTS_API_URL = os.getenv(
-    "COMMUNITY_COMPONENTS_API_URL", "https://component-registry.fedoraproject.org/"
+    "COMMUNITY_COMPONENTS_API_URL", "https://component-registry.fedoraproject.org"
 )
 
 GRIFFON_CONFIG_DIR = os.getenv("GRIFFON_API_URL", "~/.griffon")
